#!/usr/bin/env python3
# glt16 - Demo star position with PyEphem

import ephem
import numpy

d0 = ephem.Date('2016/4/30 16:00')
d1 = ephem.Date('2016/5/1 06:00')
dt = 2. / 24.  # time step in days

graz = ephem.Observer()  # Observer-Objekt
graz.lat = '46:59:28'  # gg:mm:ss
graz.lon = '15:26:23'  # gg:mm:ss
# graz.elevation = 300   # m
graz.pressure = 980  # 970 hPa = mbar
graz.date = ephem.Date(d0)

star = ephem.star('Arcturus')  # Body-Objekt

print(70 * '=')
print(graz.date)
print('Elevation    : ', graz.elevation, '     Pressure: ', graz.pressure)
print(70 * '-')
print('Previous transit: ', graz.previous_transit(star))
print('Previous rise   : ', graz.previous_rising(star))
print('Next     transit: ', graz.next_transit(star))
print('Next     set    : ', graz.next_setting(star))
print(70 * '-')

outpstr = "{:>20s} |  {:>15s}  {:>15s}".format(
    'UTC',
    'Azimuth',
    'Altitude')
print(outpstr)
print(70 * '-')
for d in numpy.arange(d0, d1 + dt, dt):
    d = ephem.Date(d)
    graz.date = d
    star.compute(graz)
    outpstr = "{:>20s} |  {:>15s}  {:>15s}".format(
        str(d),
        str(star.az),
        str(star.alt))
    # print(d, 'AZ: ', star.az, 'ALT: ', star.alt)
    print(outpstr)
